@@ -1,7 +1,7 @@
 /* ttfautohint-scripts.h */
 
 /*
- * Copyright (C) 2013-2019 by Werner Lemberg.
+ * Copyright (C) 2013-2021 by Werner Lemberg.
  *
  * This file is part of the ttfautohint library, and may only be used,
  * modified, and distributed under the terms given in `COPYING'.  By
@@ -183,6 +183,12 @@ SCRIPT(hebr, HEBR,
        HINTING_BOTTOM_TO_TOP,
        "\xD7\x9D") /* ם */
 
+SCRIPT(hmnp, HMNP,
+       "Nyiakeng Puachue Hmong",
+       HB_SCRIPT_NYIAKENG_PUACHUE_HMONG,
+       HINTING_BOTTOM_TO_TOP,
+       "\xef\xbf\xbd") /* 𞄨 */
+
 SCRIPT(kali, KALI,
        "Kayah Li",
        HB_SCRIPT_KAYAH_LI,
@@ -245,6 +251,12 @@ SCRIPT(mlym, MLYM,
        HINTING_BOTTOM_TO_TOP,
        "\xE0\xB4\xA0 \xE0\xB4\xB1") /* ഠ റ */
 
+SCRIPT(medf, MEDF,
+       "Medefaidrin",
+       HB_SCRIPT_MEDEFAIDRIN,
+       HINTING_BOTTOM_TO_TOP,
+       "\xF0\x96\xB9\xA1 \xF0\x96\xB9\x9B \xF0\x96\xB9\xAF") /* 𖹡 𖹛 𖹯 */
+
 SCRIPT(mong, MONG,
        "Mongolian",
        HB_SCRIPT_MONGOLIAN,
@@ -287,6 +299,12 @@ SCRIPT(osma, OSMA,
        HINTING_BOTTOM_TO_TOP,
        "\xF0\x90\x92\x86 \xF0\x90\x92\xA0") /* 𐒆 𐒠 */
 
+SCRIPT(rohg, ROHG,
+       "Hanifi Rohingya",
+       HB_SCRIPT_HANIFI_ROHINGYA,
+       HINTING_BOTTOM_TO_TOP,
+       "\xF0\x90\xB4\xB0") /* 𐴰 */
+
 SCRIPT(saur, SAUR,
        "Saurashtra",
        HB_SCRIPT_SAURASHTRA,
@@ -350,6 +368,12 @@ SCRIPT(vaii, VAII,
        HINTING_BOTTOM_TO_TOP,
        "\xEA\x98\x93 \xEA\x96\x9C \xEA\x96\xB4") /* ꘓ ꖜ ꖴ */
 
+SCRIPT(yezi, YEZI,
+       "Yezidi",
+       HB_SCRIPT_YEZIDI,
+       HINTING_BOTTOM_TO_TOP,
+       "\xf0\x90\xba\x8b \xf0\x90\xba\xa6") /* 𐺋 𐺦 */
+
 SCRIPT(none, NONE,
        "no script",
        HB_SCRIPT_INVALID,
